==> knative-model-5.3.0-sources.jar: io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PrometheusSourceSpecFluent<A extends PrometheusSourceSpecFluent<A>> extends Fluent<A> {


    public String getAuthTokenFile();
    public A withAuthTokenFile(String authTokenFile);
    public Boolean hasAuthTokenFile();
    public A withNewAuthTokenFile(StringBuilder arg1);
    public A withNewAuthTokenFile(int[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(char[] arg1);
    public A withNewAuthTokenFile(StringBuffer arg1);
    public A withNewAuthTokenFile(byte[] arg1,int arg2);
    public A withNewAuthTokenFile(byte[] arg1);
    public A withNewAuthTokenFile(char[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(byte[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewAuthTokenFile(String arg1);
    public String getCaCertConfigMap();
    public A withCaCertConfigMap(String caCertConfigMap);
    public Boolean hasCaCertConfigMap();
    public A withNewCaCertConfigMap(StringBuilder arg1);
    public A withNewCaCertConfigMap(int[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(char[] arg1);
    public A withNewCaCertConfigMap(StringBuffer arg1);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2);
    public A withNewCaCertConfigMap(byte[] arg1);
    public A withNewCaCertConfigMap(char[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewCaCertConfigMap(String arg1);
    public String getPromQL();
    public A withPromQL(String promQL);
    public Boolean hasPromQL();
    public A withNewPromQL(StringBuilder arg1);
    public A withNewPromQL(int[] arg1,int arg2,int arg3);
    public A withNewPromQL(char[] arg1);
    public A withNewPromQL(StringBuffer arg1);
    public A withNewPromQL(byte[] arg1,int arg2);
    public A withNewPromQL(byte[] arg1);
    public A withNewPromQL(char[] arg1,int arg2,int arg3);
    public A withNewPromQL(byte[] arg1,int arg2,int arg3);
    public A withNewPromQL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPromQL(String arg1);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public A withNewSchedule(StringBuilder arg1);
    public A withNewSchedule(int[] arg1,int arg2,int arg3);
    public A withNewSchedule(char[] arg1);
    public A withNewSchedule(StringBuffer arg1);
    public A withNewSchedule(byte[] arg1,int arg2);
    public A withNewSchedule(byte[] arg1);
    public A withNewSchedule(char[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchedule(String arg1);
    public String getServerURL();
    public A withServerURL(String serverURL);
    public Boolean hasServerURL();
    public A withNewServerURL(StringBuilder arg1);
    public A withNewServerURL(int[] arg1,int arg2,int arg3);
    public A withNewServerURL(char[] arg1);
    public A withNewServerURL(StringBuffer arg1);
    public A withNewServerURL(byte[] arg1,int arg2);
    public A withNewServerURL(byte[] arg1);
    public A withNewServerURL(char[] arg1,int arg2,int arg3);
    public A withNewServerURL(byte[] arg1,int arg2,int arg3);
    public A withNewServerURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServerURL(String arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public PrometheusSourceSpecFluent.SinkNested<A> withNewSink();
    public PrometheusSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public PrometheusSourceSpecFluent.SinkNested<A> editSink();
    public PrometheusSourceSpecFluent.SinkNested<A> editOrNewSink();
    public PrometheusSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public String getStep();
    public A withStep(String step);
    public Boolean hasStep();
    public A withNewStep(StringBuilder arg1);
    public A withNewStep(int[] arg1,int arg2,int arg3);
    public A withNewStep(char[] arg1);
    public A withNewStep(StringBuffer arg1);
    public A withNewStep(byte[] arg1,int arg2);
    public A withNewStep(byte[] arg1);
    public A withNewStep(char[] arg1,int arg2,int arg3);
    public A withNewStep(byte[] arg1,int arg2,int arg3);
    public A withNewStep(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStep(String arg1);
    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<PrometheusSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface PrometheusSourceSpecFluent<A extends PrometheusSourceSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getAuthTokenFile();
    public A withAuthTokenFile(String authTokenFile);
    public Boolean hasAuthTokenFile();
    public A withNewAuthTokenFile(StringBuilder arg1);
    public A withNewAuthTokenFile(int[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(char[] arg1);
    public A withNewAuthTokenFile(StringBuffer arg1);
    public A withNewAuthTokenFile(byte[] arg1,int arg2);
    public A withNewAuthTokenFile(byte[] arg1);
    public A withNewAuthTokenFile(char[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(byte[] arg1,int arg2,int arg3);
    public A withNewAuthTokenFile(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewAuthTokenFile(String arg1);
    public String getCaCertConfigMap();
    public A withCaCertConfigMap(String caCertConfigMap);
    public Boolean hasCaCertConfigMap();
    public A withNewCaCertConfigMap(StringBuilder arg1);
    public A withNewCaCertConfigMap(int[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(char[] arg1);
    public A withNewCaCertConfigMap(StringBuffer arg1);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2);
    public A withNewCaCertConfigMap(byte[] arg1);
    public A withNewCaCertConfigMap(char[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2,int arg3);
    public A withNewCaCertConfigMap(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewCaCertConfigMap(String arg1);
    public String getPromQL();
    public A withPromQL(String promQL);
    public Boolean hasPromQL();
    public A withNewPromQL(StringBuilder arg1);
    public A withNewPromQL(int[] arg1,int arg2,int arg3);
    public A withNewPromQL(char[] arg1);
    public A withNewPromQL(StringBuffer arg1);
    public A withNewPromQL(byte[] arg1,int arg2);
    public A withNewPromQL(byte[] arg1);
    public A withNewPromQL(char[] arg1,int arg2,int arg3);
    public A withNewPromQL(byte[] arg1,int arg2,int arg3);
    public A withNewPromQL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPromQL(String arg1);
    public String getSchedule();
    public A withSchedule(String schedule);
    public Boolean hasSchedule();
    public A withNewSchedule(StringBuilder arg1);
    public A withNewSchedule(int[] arg1,int arg2,int arg3);
    public A withNewSchedule(char[] arg1);
    public A withNewSchedule(StringBuffer arg1);
    public A withNewSchedule(byte[] arg1,int arg2);
    public A withNewSchedule(byte[] arg1);
    public A withNewSchedule(char[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3);
    public A withNewSchedule(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSchedule(String arg1);
    public String getServerURL();
    public A withServerURL(String serverURL);
    public Boolean hasServerURL();
    public A withNewServerURL(StringBuilder arg1);
    public A withNewServerURL(int[] arg1,int arg2,int arg3);
    public A withNewServerURL(char[] arg1);
    public A withNewServerURL(StringBuffer arg1);
    public A withNewServerURL(byte[] arg1,int arg2);
    public A withNewServerURL(byte[] arg1);
    public A withNewServerURL(char[] arg1,int arg2,int arg3);
    public A withNewServerURL(byte[] arg1,int arg2,int arg3);
    public A withNewServerURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServerURL(String arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<A> withNewSink();
    public io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<A> editSink();
    public io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<A> editOrNewSink();
    public io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public String getStep();
    public A withStep(String step);
    public Boolean hasStep();
    public A withNewStep(StringBuilder arg1);
    public A withNewStep(int[] arg1,int arg2,int arg3);
    public A withNewStep(char[] arg1);
    public A withNewStep(StringBuffer arg1);
    public A withNewStep(byte[] arg1,int arg2);
    public A withNewStep(byte[] arg1);
    public A withNewStep(char[] arg1,int arg2,int arg3);
    public A withNewStep(byte[] arg1,int arg2,int arg3);
    public A withNewStep(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewStep(String arg1);
    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<io.fabric8.knative.eventing.contrib.prometheus.v1alpha1.PrometheusSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}
